/*==================================================================
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corp. 2002.  All rights reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM
 * Corp.
 *
 * DISCLAIMER OF WARRANTIES.  The following [enclosed] code is
 * sample code created by IBM Corporation.  This sample code is
 * not part of any standard or IBM product and is provided to you
 * solely for the purpose of assisting you in the development of
 * your applications.  The code is provided "AS IS", without
 * warranty of any kind.  IBM shall not be liable for any damages
 * arising out of your use of the sample code, even if they have
 * been advised of the possibility of such damages.
 *===============================================================*/
package com.ibm.portal.struts.example.fileupload;

import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.upload.FormFile;
import org.apache.struts.upload.MultipartRequestHandler;

import javax.servlet.http.HttpServletRequest;

/**
 * FileUploadForm
 */
public class FileUploadForm extends ActionForm
{
    /** The file that was uploaded */
    protected FormFile formFile;

    /**
     * Get the FormFile
     *
     * @return FormFile the form file
     */
    public FormFile getFormFile() 
    {
        return formFile;
    }

    /**
     * Set the form file
     *
     * @param file the form file
     */
    public void setFormFile(FormFile formFile) 
    {
        this.formFile = formFile;
    }

    /** The file name */
    protected String fileName;
    
    /**
     * Get the file name
     *
     * @return String the file name
     */
    public String getFileName()
    {
      return this.fileName;
    }

    /**
     * Set the file name
     *
     * @param filename the file name
     */
    public void setFileName( String fileName )
    {
      this.fileName = fileName;
    }
    
    /** The file size */
    protected int fileSize;
    
    /**
     * Get the file size
     *
     * @return int the file size
     */
    public int getFileSize()
    {
      return this.fileSize;
    }
    
    /**
     * Set the file size
     *
     * @param fileSize the file size
     */
    public void setFileSize( int fileSize )
    {
      this.fileSize = fileSize;
    }

    /**
     * Reset
     *
     */
    public void reset() {
        formFile = null;
        fileSize = 0;
        fileName = "none";
    }

    

    /**
     * Validate the file upload. Check for max length error
     * 
     * @param mapping the action mapping
     * @param request the http servlet request object     
     * @return ActionErrors the action errors.
     */
    public ActionErrors validate(ActionMapping mapping, HttpServletRequest request)
    {
        ActionErrors errors = null;
        //has the maximum length been exceeded?
        Boolean maxLengthExceeded = (Boolean)
                request.getAttribute(MultipartRequestHandler.ATTRIBUTE_MAX_LENGTH_EXCEEDED);
        if ((maxLengthExceeded != null) && (maxLengthExceeded.booleanValue() == true))
        {
            errors = new ActionErrors();
            errors.add("MaxLengthExceeded", new ActionError("MaxLengthExceeded"));
        }
        return errors;

    }
}
