/*==================================================================
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corp. 2002.  All rights reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM
 * Corp.
 *
 * DISCLAIMER OF WARRANTIES.  The following [enclosed] code is
 * sample code created by IBM Corporation.  This sample code is
 * not part of any standard or IBM product and is provided to you
 * solely for the purpose of assisting you in the development of
 * your applications.  The code is provided "AS IS", without
 * warranty of any kind.  IBM shall not be liable for any damages
 * arising out of your use of the sample code, even if they have
 * been advised of the possibility of such damages.
 *===============================================================*/
package com.ibm.portal.struts.example.fileupload.actions;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.upload.FormFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.portal.struts.example.fileupload.FileUploadForm;

/**
 * Action to Display the File information
 */
public class DisplayFileAction extends Action
{
   /** The <code>Log</code> instance for this application. */
   private static Log log = 
       LogFactory.getLog (DisplayFileAction.class);
   
   /**
    * Display Action. Takes the information from the FileUploadForm
    * 
    * @param mapping the action mapping
    * @param form the action form
    * @param request the http servlet request
    * @param response the http servlet response
    * @return ActionForward the action forward
    */
   public ActionForward execute(ActionMapping mapping,
                                 ActionForm form,
                                 HttpServletRequest request,
                                 HttpServletResponse response)
   throws Exception 
   {

      ActionForward forward = mapping.findForward("failure");
      
      if ( form instanceof FileUploadForm )
      {
         FileUploadForm fileUploadForm = (FileUploadForm) form;
         
         // get the form file
         FormFile formFile = fileUploadForm.getFormFile();
         if (formFile != null )
         {
            log.debug("file name is " + formFile.getFileName() + 
                      " and file size is " + formFile.getFileSize()  );

            // get some basic information from the file
            fileUploadForm.setFileName( formFile.getFileName() );
            fileUploadForm.setFileSize( formFile.getFileSize() );

            forward = mapping.findForward("success");
            formFile.destroy();
         }
         
         // this is where you would do something interesing with the file. We are just going 
         // to display the the name and file size.
      }
      return forward;                                 

   }
}
