/*********************************************************************
 * Licensed Materials - PropertyImpl of IBM                              *
 *                                                                   *
 * 5724-B88                                                          *
 *                                                                   *
 *  Copyright IBM Corp.  2001, 2002    All Rights Reserved.         *
 *                                                                   *
 * US Government Users Restricted Rights - Use, duplication or       *
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp. *
 *********************************************************************/

package com.ibm.websphere.query.base;


/**
	<P>The Operator class represents an operator in the query framework. It can be used in a 
	predicate, an order by, and where ever appropriate.
	
	<P>This class contains a name, and a metadata that encapsulates information about mapping to a 
	domain specific operator.
 */
public class Operator implements IOperator
{
  private String name = "";
  private Object metadata = null;

  /**
  	Creates a new Operator instance, default constructor.
   */
  public Operator()
  {
  }
  /**
  	Creates a new Operator instance with the given name.
   */
  public Operator(String newName)
  {
    name = newName;
  }
  /**
  	Returns the operator name.
   */
  public String getName()
  {
    return name;
  }
  /**
  	Sets the operator name.
   */
  public void setName(String newName)
  {
    name = newName;
  }
  /**
  	Creates a new Operator instance with the given name, and metadata object.
   */
  public Operator(String newName, Object newMetadata)
  {
    name = newName;
    metadata = newMetadata;
  }
  /**
  	Builds a query string for the operator.
   */
  public String buildString(ISelectQueryCallback builder) throws QueryException
  {
    return builder.buildOperator(this);
  }
  public void buildString(ISelectQueryCallback builder, StringBuffer sb) throws QueryException
  {
    builder.buildOperator(this, sb);
  }
  /**
  	Tests for equality with the given object.
   */
  public boolean equals(Object o)
  {
    boolean eq = true;

    if (o instanceof Operator)
    {
      Operator op = (Operator) o;

      if (name != null)
      {
        eq = name.equals(op.name);
      }
      else
      {
        eq = (op.name == null);
      }

      if (eq)
      {
        if (metadata != null)
        {
          eq = metadata.equals(op.metadata);
        }
        else
        {
          eq = (op.metadata == null);
        }
      }
    }
    else
    {
      eq = false;
    }

    return eq;
  }
  /**
  	Returns the metadata object, the domain specific object the operator is mapped to.
   */
  public Object getMetadata()
  {
    return metadata;
  }
  /**
  	Computes a hash code for the operator.
   */
  public int hashCode()
  {
    int hashCode = 0;

    if (name != null)
      hashCode = name.hashCode();

    if (metadata != null)
      hashCode = hashCode ^ metadata.hashCode();

    return hashCode;
  }
  /**
  	Sets the metadata object, the domain specific object the operator is mapped to.
   */
  public void setMetadata(java.lang.Object newMetadata)
  {
    metadata = newMetadata;
  }
}
