package com.ibm.websphere.query.base;


public abstract class Query implements IQuery
{
  private PredicateBase predicate;
  private IFrom from;

  private boolean cacheable = true;

  /**
   * @see com.ibm.websphere.query.base.IQuery#getPredicate()
   */
  public PredicateBase getPredicate()
  {
    return predicate;
  }

  /**
   * @see com.ibm.websphere.query.base.IQuery#setPredicate(PredicateBase)
   */
  public void setPredicate(PredicateBase predicate)
  {
    this.predicate = predicate;
  }

  /**
   * @see com.ibm.websphere.query.base.IQuery#getFrom()
   */
  public IFrom getFrom()
  {
    return from;
  }

  /**
   * @see com.ibm.websphere.query.base.IQuery#setFrom(com.ibm.websphere.query.base.IFrom)
   */
  public void setFrom(IFrom from)
  {
    this.from = from;
  }

  
  /**
	Builds a predicate string for the query by delegating the operation to the given query
	builder callback.
   */
  public String buildPredicateString(ISelectQueryCallback builder) throws QueryException
  {
	if (builder == null)
	{
	  throw new QueryException("Query builder callback is missing.");
	}
	else
	{
	  return builder.buildPredicate(this);
	}
  }
  public void buildPredicateString(ISelectQueryCallback builder, StringBuffer sb) throws QueryException
  {
	if (builder == null)
	{
	  throw new QueryException("Query builder callback is missing.");
	}
	else
	{
	  builder.buildPredicate(this, sb);
	}
  }


        /**
         * @return
         */
        public boolean isCacheable() {
                return cacheable;
        }

        /**
         * @param b
         */
        public void setCacheable(boolean b) {
                cacheable = b;
        }

}
