package com.ibm.websphere.query.callbacks;

import com.ibm.websphere.query.base.IArithmeticCondition;
import com.ibm.websphere.query.base.IAttribute;
import com.ibm.websphere.query.base.ICondition;
import com.ibm.websphere.query.base.IDeleteQuery;
import com.ibm.websphere.query.base.IFrom;
import com.ibm.websphere.query.base.IFunction;
import com.ibm.websphere.query.base.IJoin;
import com.ibm.websphere.query.base.ILimit;
import com.ibm.websphere.query.base.IOperator;
import com.ibm.websphere.query.base.IOrderBy;
import com.ibm.websphere.query.base.IOrderByExpression;
import com.ibm.websphere.query.base.IPredicate;
import com.ibm.websphere.query.base.IQuery;
import com.ibm.websphere.query.base.ISelect;
import com.ibm.websphere.query.base.ISelectQuery;
import com.ibm.websphere.query.base.ISelectQueryCallback;
import com.ibm.websphere.query.base.ITable;
import com.ibm.websphere.query.base.IValue;
import com.ibm.websphere.query.base.QueryException;


public abstract class SelectQueryCallbackAdapter implements ISelectQueryCallback {
	
	static final String UNSUPPORTED_QUERY = "Unsupported Query";
	
	public abstract String buildAttribute(IAttribute attribute) throws QueryException;

	public  void buildAttribute(IAttribute attribute, StringBuffer sb) throws QueryException {
		sb.append(buildAttribute(attribute));
	}
	
	public abstract String buildCondition(ICondition condition) throws QueryException;

	public void buildCondition(ICondition condition, StringBuffer sb) throws QueryException {
		sb.append(buildCondition(condition));
	}

	public abstract String buildFunction(IFunction function) throws QueryException; 

	public void buildFunction(IFunction function, StringBuffer sb) throws QueryException {
		sb.append(buildFunction(function));
	}
	
	public abstract String buildArithmeticCondition(IArithmeticCondition arithmeticCondition) throws QueryException;

	public void buildArithmeticCondition(IArithmeticCondition arithmeticCondition, StringBuffer sb) throws QueryException {
		sb.append(buildArithmeticCondition(arithmeticCondition));
	}

	public abstract String buildOperator(IOperator operator) throws QueryException;

	public void buildOperator(IOperator operator, StringBuffer sb) throws QueryException {
		sb.append(buildOperator(operator));
	}
	
	public abstract String buildOrderBy(IOrderBy orderBy) throws QueryException;

	public void buildOrderBy(IOrderBy orderBy, StringBuffer sb) throws QueryException {
		sb.append(buildOrderBy(orderBy));
	}
	
	public abstract String buildOrderBy(ISelectQuery selectQuery) throws QueryException;

	 public void buildOrderBy(ISelectQuery selectQuery, StringBuffer sb) throws QueryException {
	 	sb.append(buildOrderBy(selectQuery));
	 }
	 
	public abstract String buildOrderByExpression(IOrderByExpression orderByExpression) throws QueryException;
	
	public void buildOrderByExpression(IOrderByExpression orderByExpression, StringBuffer sb) throws QueryException {
		sb.append(buildOrderByExpression(orderByExpression));
	}
	 
	public abstract String buildLimit(ILimit limit) throws QueryException;
	
	public void buildLimit(ILimit limit, StringBuffer sb) throws QueryException {
		sb.append(buildLimit(limit));
	}
	
	public abstract String buildLimit(ISelectQuery selectQuery) throws QueryException;
	
	public void buildLimit(ISelectQuery selectQuery, StringBuffer sb) throws QueryException {
		sb.append(selectQuery);
	}
	  
	public abstract String buildPredicate(IPredicate predicate) throws QueryException;
	  
	public void buildPredicate(IPredicate predicate, StringBuffer sb) throws QueryException {
		sb.append(buildPredicate(predicate));
	}
	  
	public abstract String buildPredicate(IQuery query) throws QueryException;
	  
	public void buildPredicate(IQuery query, StringBuffer sb) throws QueryException {
		sb.append(buildPredicate(query));
	}
	  
	public abstract String buildQuery(IQuery query) throws QueryException;

	public void buildQuery(IQuery query, StringBuffer sb) throws QueryException {
		sb.append(buildQuery(query));
	}
	  
	public abstract String buildSelectQuery(ISelectQuery selectQuery) throws QueryException;

	public void buildSelectQuery(ISelectQuery selectQuery, StringBuffer sb) throws QueryException {
		sb.append(buildSelectQuery(selectQuery));
	}
	
	public abstract String buildValue(IValue value) throws QueryException;
	
	public void buildValue(IValue value, StringBuffer sb) throws QueryException {
		sb.append(buildValue(value));
	}
	
	public void buildDeleteQuery(IDeleteQuery deleteQuery, StringBuffer sb) throws QueryException {
		throw new QueryException(UNSUPPORTED_QUERY);
	}
	
	public void buildFrom(IFrom from, StringBuffer sb) throws QueryException {
		throw new QueryException(UNSUPPORTED_QUERY);
	}
	
	public void buildFrom(IDeleteQuery deleteQuery, StringBuffer sb) throws QueryException {
		throw new QueryException(UNSUPPORTED_QUERY);
	}
	
	public void buildFrom(ISelectQuery selectQuery, StringBuffer sb) throws QueryException {
		throw new QueryException(UNSUPPORTED_QUERY);
	}
	
	public void buildJoin(IJoin join, StringBuffer sb) throws QueryException {
		throw new QueryException(UNSUPPORTED_QUERY);
	}
	
	public void buildSelect(ISelect select, StringBuffer sb) throws QueryException {
		throw new QueryException(UNSUPPORTED_QUERY);
	}
	
	public void buildTable(ITable selectQuery, StringBuffer sb) throws QueryException {
		throw new QueryException(UNSUPPORTED_QUERY);
	}
	

	

	
}