package com.ibm.etools.portal.portletexamples.content.legacy;

import java.io.IOException;
import java.io.InputStream;

import org.apache.jetspeed.portlet.*;
import org.apache.jetspeed.portlet.event.*;
import org.apache.jetspeed.portlet.service.ContentAccessService;
import org.apache.jetspeed.portlet.service.PortletServiceException;
import org.apache.jetspeed.portlet.service.PortletServiceNotFoundException;
import org.apache.jetspeed.portlet.service.PortletServiceUnavailableException;

import java.net.MalformedURLException;

/**
 *
 * A sample portlet to demonstrate remote content access using ContentAccessService for IBM legacy API
 * 
 */
public class ContentAccessServicePortlet extends PortletAdapter implements ActionListener {

	public static final String VIEW_JSP = "/jsp/ContentAccessServicePortletView."; // JSP file name to be rendered on the view mode //$NON-NLS-1$
	public static final String EDIT_JSP = "/jsp/ContentAccessServicePortletEdit."; // JSP file name to be rendered on the edit mode //$NON-NLS-1$
	public static final String HELP_JSP = "/jsp/ContentAccessServicePortletHelp."; // JSP file name to be rendered on the help mode //$NON-NLS-1$
	public static final String CONFIG_JSP = "/jsp/ContentAccessServicePortletConfig."; // JSP file name to be rendered on the configure mode //$NON-NLS-1$
	public static final String ERROR_JSP = "/jsp/ContentAccessServicePortletError."; // JSP file name to be rendered on the configure mode //$NON-NLS-1$
	public static final String HELP_BEAN = "ContentAccessServicePortletHelpBean"; // Bean name for the help mode request //$NON-NLS-1$
	public static final String SESSION_BEAN = "ContentAccessServicePortletSessionBean"; // Bean name for the portlet session //$NON-NLS-1$
	public static final String EDIT_FORM_ACTION = "changeOption"; // Action name for the edit form //$NON-NLS-1$
	public static final String CONFIG_FORM_ACTION = "changeURI"; // Action name for the config form //$NON-NLS-1$
	public static final String CANCEL = "cancelURI"; // Parameter name for general cancel button //$NON-NLS-1$
	public static final String URL = "url"; // Parameter name for config param //$NON-NLS-1$
	public static final String FILTER_OPTION = "filterOption"; // Parameter name for edit param //$NON-NLS-1$
	public static final String DIRECT = "direct"; //$NON-NLS-1$
	public static final String NUMBER_COUNT = "numberCount"; //$NON-NLS-1$
	public static final String CURRENT_URL = "currentURL"; //$NON-NLS-1$
	public static final String ERROR = "error"; //$NON-NLS-1$

	private ContentAccessService cas = null;
	/**
	 * @see org.apache.jetspeed.portlet.Portlet#init(PortletConfig)
	 */
	public void init(PortletConfig portletConfig) throws UnavailableException {
		super.init(portletConfig);
		try {
			cas =
				(ContentAccessService) portletConfig.getContext().getService(
					ContentAccessService.class);
		} catch (PortletServiceUnavailableException ex) {
			if (getPortletLog().isErrorEnabled()) {
				getPortletLog().error(Messages.getString("ContentAccessServicePortlet.ContentAccessServicePortlet_(IBM)_error___1"), ex); //$NON-NLS-1$
			}
		} catch (PortletServiceNotFoundException ex) {
			if (getPortletLog().isErrorEnabled()) {
				getPortletLog().error(Messages.getString("ContentAccessServicePortlet.ContentAccessServicePortlet_(IBM)_error___1"), ex); //$NON-NLS-1$
			}
		}
	}

	/**
	 * @see org.apache.jetspeed.portlet.PortletAdapter#doView(PortletRequest, PortletResponse)
	 */
	public void doView(PortletRequest request, PortletResponse response)
		throws PortletException, IOException {
		String errorMessage = (String) request.getAttribute(ERROR);
		if (errorMessage != null) {
			invokeErrorJSP(request, response, errorMessage, null);
			return;
		}
		// Check if portlet session exists		
		ContentAccessServicePortletSessionBean sessionBean = getSessionBean(request);
		if (sessionBean == null) {
			errorMessage = Messages.getString("ContentAccessServicePortlet.<b>NO_PORTLET_SESSION_YET</b>_3");
			invokeErrorJSP(request, response, errorMessage, null);
			return;
		}
		String filterOption = sessionBean.getFilterOption();
		if (filterOption == null)
			filterOption = DIRECT;

		PortletSettings setting = request.getPortletSettings();
		String url = setting.getAttribute(URL);
		if (url == null || url.length() == 0) {
			errorMessage = Messages.getString("ContentAccessServicePortlet.<b>Please_specify_the_remote_content_URL.</b>_5");
			invokeErrorJSP(request, response, errorMessage, null);
			return;
		}
		if (filterOption.equals(DIRECT)) {
			includeRemoteResource(url, request, response);
		} else {
			filterRemoteResource(url, request, response);
		}
	}

	/**
	 * @see org.apache.jetspeed.portlet.PortletAdapter#doEdit(PortletRequest, PortletResponse)
	 */
	public void doEdit(PortletRequest request, PortletResponse response)
		throws PortletException, IOException {

		PortletURI cancelURI = response.createReturnURI();
		request.setAttribute(CANCEL, cancelURI.toString());

		PortletURI submitURI = response.createReturnURI();
		submitURI.addAction(EDIT_FORM_ACTION);
		request.setAttribute(EDIT_FORM_ACTION, submitURI.toString());

		// Invoke the JSP to render        		
		getPortletConfig().getContext().include(EDIT_JSP + getJspExtension(request), 
			request, response);
	}

	/**
	 * @see org.apache.jetspeed.portlet.PortletAdapter#doHelp(PortletRequest, PortletResponse)
	 */
	public void doHelp(PortletRequest request, PortletResponse response)
		throws PortletException, IOException {

		// Invoke the JSP to render        		
		getPortletConfig().getContext().include(HELP_JSP + getJspExtension(request),
			request, response);
	}

	/**
	 * @see org.apache.jetspeed.portlet.PortletAdapter#doConfigure(PortletRequest, PortletResponse)
	 */
	public void doConfigure(PortletRequest request, PortletResponse response)
		throws PortletException, IOException {
		PortletURI cancelURI = response.createReturnURI();
		request.setAttribute(CANCEL, cancelURI.toString());

		PortletURI changeURI = response.createReturnURI();
		changeURI.addAction(CONFIG_FORM_ACTION);
		request.setAttribute(CONFIG_FORM_ACTION, changeURI.toString());

		PortletSettings setting = request.getPortletSettings();
		String currentUrl = setting.getAttribute(URL);
		request.setAttribute(CURRENT_URL, currentUrl);

		// Invoke the JSP to render        		
		getPortletConfig().getContext().include(CONFIG_JSP + getJspExtension(request),
			request, response);
	}

	/**
	 * @see org.apache.jetspeed.portlet.event.ActionListener#actionPerformed(ActionEvent)
	 */
	public void actionPerformed(ActionEvent event) throws PortletException {
		if (getPortletLog().isDebugEnabled())
			getPortletLog().debug(Messages.getString("ContentAccessServicePortlet.ContentAccessServicePortlet_(IBM)_ActionListener_-_actionPerformed_called_13")); //$NON-NLS-1$
		// ActionEvent handler
		String actionString = event.getActionString();
		// Add action string handler here
		PortletRequest request = event.getRequest();
		ContentAccessServicePortletSessionBean sessionBean = getSessionBean(request);

		String errorMessage = null;
		if (CONFIG_FORM_ACTION.equals(actionString)) {
			String newUrl = request.getParameter(URL);
			if (newUrl == null || newUrl.length() == 0) {
				errorMessage =
					Messages.getString(
						"ContentAccessServicePortlet.ContentAccessServicePortlet_(IBM)_error__Invalid_url_is_specified._14");
				request.setAttribute(ERROR, errorMessage);
				return;
			}
			PortletSettings setting = request.getPortletSettings();
			setting.setAttribute(URL, newUrl);
			try {
				setting.store();
			} catch (IOException ex) {
				errorMessage = ex.toString();
				request.setAttribute(ERROR, errorMessage);
			}
		} else if (EDIT_FORM_ACTION.equals(actionString)) {
			sessionBean.setFilterOption(request.getParameter(FILTER_OPTION));
		}
	}

	/**
	 * Get SessionBean.
	 * 
	 * @param request PortletRequest
	 * @return ContentAccessServicePortletSessionBean
	 */
	private ContentAccessServicePortletSessionBean getSessionBean(PortletRequest request) {
		PortletSession session = request.getPortletSession();
		if (session == null)
			return null;
		ContentAccessServicePortletSessionBean sessionBean =
			(ContentAccessServicePortletSessionBean) session.getAttribute(SESSION_BEAN);
		if (sessionBean == null) {
			sessionBean = new ContentAccessServicePortletSessionBean();
			session.setAttribute(SESSION_BEAN, sessionBean);
		}
		return sessionBean;
	}

	/**
	 * Returns the file extension for the JSP file
	 * 
	 * @param request PortletRequest
	 * @return JSP extension 
	 */
	private static String getJspExtension(PortletRequest request) {
		return "jsp"; //$NON-NLS-1$
	}
	
	/**
	 * Access remote resources and render directly using ContentAccessService
	 * 
	 * @param url
	 * @param request
	 * @param response
	 * @throws PortletException
	 * @throws IOException
	 */
	private void includeRemoteResource(String url, PortletRequest request, PortletResponse response) 
	throws PortletException, IOException {
		String errorMessage = null;
		try {
			if (cas != null)
				cas.include(url, request, response);
		} catch (PortletServiceException ex) {
			errorMessage = Messages.getString("ContentAccessServicePortlet.ContentAccessServicePortlet_(IBM)_error___1"); //$NON-NLS-1$
			invokeErrorJSP(request, response, errorMessage, ex);
		} catch (MalformedURLException ex) {
			errorMessage = Messages.getString("ContentAccessServicePortlet.ContentAccessServicePortlet_(IBM)_error___1"); //$NON-NLS-1$
			invokeErrorJSP(request, response, errorMessage, ex);
		}
	}
	
	
	/**
	 * Access remote resources and filter the content using ContentAcessService
	 * 
	 * @param url
	 * @param request
	 * @param response
	 * @throws PortletException
	 * @throws IOException
	 */
	private void filterRemoteResource(String url, PortletRequest request, PortletResponse response) 
	throws PortletException, IOException {
		String errorMessage = null;
		InputStream in = null;
		int numberCount = -1;

		try {
			if (cas != null) {
				in = cas.getInputStream(url, request, response);
				numberCount = SimpleNumberCounter.count(in);
			}
		} catch (PortletServiceException ex) {
			errorMessage = Messages.getString("ContentAccessServicePortlet.ContentAccessServicePortlet_(IBM)_error___1"); //$NON-NLS-1$
			invokeErrorJSP(request, response, errorMessage, ex);
			return;
		} catch (MalformedURLException ex) {
			errorMessage = Messages.getString("ContentAccessServicePortlet.ContentAccessServicePortlet_(IBM)_error___1"); //$NON-NLS-1$
			invokeErrorJSP(request, response, errorMessage, ex);
			return;
		} catch (IOException ex) {
			errorMessage = Messages.getString("ContentAccessServicePortlet.ContentAccessServicePortlet_(IBM)_error___1"); //$NON-NLS-1$
			invokeErrorJSP(request, response, errorMessage, ex);
			return;
		} finally {
			try {
				if (in != null)
					in.close();
			} catch (IOException ex) {
				errorMessage = Messages.getString("ContentAccessServicePortlet.ContentAccessServicePortlet_(IBM)_error___1"); //$NON-NLS-1$
				invokeErrorJSP(request, response, errorMessage, ex);
				return;
			}
		}
		request.setAttribute(NUMBER_COUNT, String.valueOf(numberCount));
		request.setAttribute(CURRENT_URL, url);
		getPortletConfig().getContext().include(VIEW_JSP + getJspExtension(request),
			request, response);
	}
	
	/**
	 * log error message and render error JSP
	 * 
	 * @param request
	 * @param response
	 * @param errorMessage
	 * @param exception
	 * @throws PortletException
	 * @throws IOException
	 */
	private void invokeErrorJSP(PortletRequest request, PortletResponse response, String errorMessage, Throwable exception) 
	throws PortletException, IOException {
		if (exception != null) {
			if (getPortletLog().isErrorEnabled()) {
				getPortletLog().error(errorMessage, exception);
			}
		} else {
			getPortletLog().error(errorMessage);
		}
		request.setAttribute(ERROR, errorMessage);
		getPortletConfig().getContext().include(ERROR_JSP + getJspExtension(request),
			request, response);
	}

}
