/*
 * RangeIterator.java
 *
 * This file is part of the specification for the
 * Java Content Repository API
 */
package javax.jcr;

import java.util.Iterator;

/**
 * Extends <code>Iterator</code> with a
 * <code>skip</code> method. The base interface of all type-specific
 * iterators in the javax.jcr and its subpackages.
 *
 * @author Peeter Piegaze
 */
public interface RangeIterator extends Iterator {

    /**
     * Skip a number of items in the iterator.
     */
    public void skip(int skipNum);

    /**
     * Returns number of elements in the iterator.
     * If this information is unavailable, returns -1.
     *
     * @return a long
     */
    public long getSize();

    /**
     * Returns current position within the iterator. The number
     * returned is the index of the next item in the iterator,
     * i.e. the one that will be returned on the
     * the subsequent <code>next</code> call.
     * If this information is unavailable, returns -1.
     *
     * @return a long
     */
    public long getPosition();
}
