/*
 * SimpleValue.java
 *
 * This file is part of the specification for the
 * Java Content Repository API
 */
package javax.jcr;

import java.util.Calendar;

/**
 * A <code>ReferenceValue</code> provides an implementation
 * of the <code>Value</code> interface representing a reference value
 * (i.e. an reference to an existing node via UUID).
 *
 * 
 */
public class ReferenceValue extends BaseValue {

    public static final int TYPE = PropertyType.REFERENCE;

    private String uuid = null;

    /**
     * Constructs a <code>ReferenceValue</code> object representing an existing node     
     * by UUID.
     *
     * @param UUID the uuid this <code>ReferenceValue</code> should represent
     */
    public ReferenceValue(String UUID) {
        super(TYPE);
        this.uuid = UUID;
    }

    //----------------------------------------------------------------< Value >
    /**
     * @see Value#getDate
     */
    public Calendar getDate() throws ValueFormatException, IllegalStateException, RepositoryException {
        setValueConsumed();

        throw new ValueFormatException("conversion to date failed: inconvertible types");
    }

    /**
     * @see Value#getLong
     */
    public long getLong() throws ValueFormatException, IllegalStateException, RepositoryException {
        setValueConsumed();

        throw new ValueFormatException("conversion to long failed: inconvertible types");
    }

    /**
     * @see Value#getBoolean
     */
    public boolean getBoolean() throws ValueFormatException, IllegalStateException, RepositoryException {
        setValueConsumed();

        throw new ValueFormatException("conversion to boolean failed: inconvertible types");
    }

    /**
     * @see Value#getDouble
     */
    public double getDouble() throws ValueFormatException, IllegalStateException, RepositoryException {
        setValueConsumed();

        throw new ValueFormatException("conversion to double failed: inconvertible types");
    }

    /**
     * @see Value#getString
     */
    public String getString() throws ValueFormatException, IllegalStateException, RepositoryException {
        setValueConsumed();

        if (uuid != null) {
            return uuid;
        } else {
            throw new ValueFormatException("empty value");
        }
    }
    
  public boolean equals(Object obj)
  {
    boolean equals = false;
    if (obj instanceof ReferenceValue)
    {
      ReferenceValue refValue = (ReferenceValue)obj;
      if (refValue.uuid != null && uuid != null)
      {
        equals = refValue.uuid.equals(uuid);
      }
      else if (refValue.uuid == null && uuid == null)
      {
        equals = true;
      }
    }
    return equals;
  }
  
  public int hashCode()
  {
    int hashCode = 37;
    if (uuid != null)
    {
      hashCode = uuid.hashCode();
    }
    return hashCode;
  }
}
