/*
 * Repository.java
 *
 * This file is part of the specification for the
 * Java Content Repository API
 */
package javax.jcr;

import javax.jcr.access.AccessDeniedException;

/**
 * The entry point into the content repository.
 * Represents the entry point into the content repository. Typically the object
 * implementing this interface will be acquired from a JNDI-compatible
 * naming and directory service.
 * @author Peeter Piegaze
 * @author Stefan Guggisberg
  */
public interface Repository {

    /**
     * Login, creating a new ticket for the given credentials.
     * If login fails, a <code>LoginException</code> is thrown and no valid
     * ticket is generated. How the repository treats an attempt to connect with
     * <code>null</code> credentials is a matter of implementation. One
     * possibility is to allow an anonymous connection in these cases.
     * <p>
     * <b>Level 2:</b>
     * <p>
     * Returns a <code>{@link javax.jcr.xa.XATicket}</code> object
     * <p>
     * @param credentials The credentials to authenticate with
     * @return a valid ticket for the user to access the repository.
     * @throws LoginException if the login authentication fails.
     */
    public Ticket login(Credentials credentials) throws LoginException;

    /**
     * Deletes a workspace from the repository.
     * 
     * @param name Name of the workspace to be deleted.
     * @param ticket Ticket identifying the access permissions necessary to delete the workspace.
     * 
     * @throws AccessDeniedException if the ticket has insufficient authority to delete the root node of the workspace.
     * @throws RepositoryException if there is no workspace with the specified name or another error occurs.
     */
    public void deleteWorkspace(String name, Ticket ticket)
      throws AccessDeniedException, RepositoryException;
}
