/*
 * Lock.java
 *
 * This file is part of the specification for the
 * Java Content Repository API
 */
package javax.jcr.lock;

import javax.jcr.Item;


/**
 * Represents a lock placed on an item.
 * <p>
 * <b>Level 2 only</b>
 * <p>
 * A lock is associated with an item and a user (not a ticket)
 *
 * @author Peeter Piegaze
 */
public interface Lock {

    /**
     * Returns the user ID of the user who has this lock.
     *
     * @return a user ID.
     */
    public String getOwner();

    /**
     * Returns the type of this lock. This standard specifies only one
     * type of lock: <code>LockType.WRITE_LOCK</code> though more can be
     * supported by a specific JCR implementation.
     *
     * @return the type of this lock.
     *
     * @see LockCapabilities#getSupportedLockTypes
     * @see LockType
     */
    public int getType();

    /**
     * Returns <code>true</code> if this lock is a shared lock.
     *
     * @return <code>true</code> if this is a shered lock, <code>false</code>
     * otherwise.
     */
    public boolean isShared();

    /**
     * Returns the locked item.
     *
     * @return an <code>Item</code>.
     */
    public Item getItem();

    /**
     * Returns true if this Lock object represents a currently existing
     * lock on some item. Returns false if the actual lock corresponding
     * to this Lock object has been removed but a reference to this Lock
     * object still exists. Ths indicates that this Lock object is "dead"
     * and its reference should be discarded so that the object can be
     * garbage collected.
     */
    public boolean isLive();
}
