/*
 * XATicket.java
 *
 * This file is part of the specification for the
 * Java Content Repository API
 */
package javax.jcr.xa;

import javax.jcr.Ticket;
import javax.transaction.xa.XAResource;

/**
 * The <code>XATicket</code> interface extends the capability of
 * <code>Ticket</code> by adding access to a JCR repository's support for
 * the Java Transaction API (JTA).
 * <p>
 * <b>Level 2 only</b>
 * <p>
 * This support takes the form of a <code>javax.transaction.xa.XAResource</code>
 * object. The functionality of this object closely resembles that defined by
 * the standard X/Open XA Resource interface.
 * <p>
 * This interface is used by the transaction manager; an application does not
 * use it directly.
 *
 * @author Stefan Guggisberg
 */
public interface XATicket extends Ticket {

    /**
     * Retrieves an <code>XAResource</code> object that the transaction manager
     * will use to manage this <code>XATicket</code> object's participation in
     * a distributed transaction.
     *
     * @return the <code>XAResource</code> object.
     */
    public XAResource getXAResource();
}